Interned

Struct Interned 

#[repr(transparent)]
pub struct Interned<'a, T: ?Sized>(pub &'a T, pub Private);
An Interned value is one that is referentially comparable. That is, the interned value is unique in memory, simplifying its equality and hashing implementation.

Comparing Interned values via PartialOrd or Ord will still dereference to the wrapped pointers, and as such, may produce results inconsistent with PartialEq or Eq.

Tuple Fields

0: &'a T1: Private

Implementations

Source

impl<'a, T: ?Sized> Interned<'a, T>

pub fn as_ptr(interned: &Self) -> *const T

Gets the internal value as a pointer

pub fn to_ref(&self) -> &'a T

Gets the internal value as a reference with the interner’s lifetime

Source

impl<'a, T: ?Sized> Interned<'a, T>

pub(super) fn new(value: &'a T) -> Self