#[repr(transparent)]pub struct Interned<'a, T: ?Sized>(pub &'a T, pub Private);Expand description
An Interned value is one that is referentially comparable. That is, the interned value is unique in memory, simplifying its equality and hashing implementation.
Comparing Interned values via PartialOrd or Ord will still dereference to the wrapped pointers, and as such, may produce results inconsistent with PartialEq or Eq.
Tuple Fields
0: &'a T1: PrivateImplementations